@@ -9,7 +9,7 @@
 info <- function(species=NULL, state=NULL, check.it=TRUE) {
   ## return information for one or more species in thermo$obigt
   ## if no species are requested, summarize the available data  20101129
-  thermo <- get("thermo")
+  thermo <- get("thermo", CHNOSZ)
   if(is.null(species)) {
     message("info: 'species' is NULL; summarizing information about thermodynamic data...")
     message(paste("thermo$obigt has", nrow(thermo$obigt[thermo$obigt$state=="aq", ]), "aqueous,",
@@ -27,7 +27,7 @@ info <- function(species=NULL, state=NULL, check.it=TRUE) {
   ## run info.numeric or info.character depending on the input type
   if(is.numeric(species)) {
     out <- lapply(species, info.numeric, check.it)
-    # if we different states the column names could be different
+    # if we have different states the column names could be different
     if(length(unique(unlist(lapply(out, names)))) > ncol(thermo$obigt)) {
       # make them the same as thermo$obigt
       out <- lapply(out, function(row) {
@@ -36,6 +36,8 @@ info <- function(species=NULL, state=NULL, check.it=TRUE) {
     }
     # turn the list into a data frame
     out <- do.call(rbind, out)
+    # ensure that the rownames are numeric values (not names possibly inherited from retrieve()) 20190224
+    if(!is.null(attr(species, "names"))) row.names(out) <- species
   } else {
     # state and species should be same length
     if(!is.null(state)) {
@@ -63,7 +65,7 @@ info <- function(species=NULL, state=NULL, check.it=TRUE) {
 info.text <- function(ispecies) {
   # a textual description of species name, formula, source, e.g.
   # CO2 [CO2(aq)] (SSW01, SHS89, 11.Oct.07)
-  this <- get("thermo")$obigt[ispecies, ]
+  this <- get("thermo", CHNOSZ)$obigt[ispecies, ]
   sourcetext <- this$ref1
   ref2 <- this$ref2
   if(!is.na(ref2)) sourcetext <- paste(sourcetext, ref2, sep=", ")
@@ -78,7 +80,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
   # thermo$obigt$[species|abbrv|formula] or NA otherwise
   # a match to thermo$obigt$state is also required if 'state' is not NULL
   # (first occurence of a match to species is returned otherwise)
-  thermo <- get("thermo")
+  thermo <- get("thermo", CHNOSZ)
   # find matches for species name, abbreviation or formula
   matches.species <- thermo$obigt$name==species | thermo$obigt$abbrv==species | thermo$obigt$formula==species
   # since thermo$obigt$abbrv contains NAs, convert NA results to FALSE
@@ -101,7 +103,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
         eos <- protein.obigt(ip, state=state)
         # the real assignment work 
         nrows <- suppressMessages(mod.obigt(eos))
-        thermo <- get("thermo", "CHNOSZ")
+        thermo <- get("thermo", CHNOSZ)
         matches.species <- rep(FALSE, nrows)
         matches.species[nrows] <- TRUE
       } else return(NA)
@@ -168,7 +170,7 @@ info.character <- function(species, state=NULL, check.protein=TRUE) {
 info.numeric <- function(ispecies, check.it=TRUE) {
   # from a numeric species index in 'ispecies' return the 
   # thermodynamic properties and equations-of-state parameters
-  thermo <- get("thermo")
+  thermo <- get("thermo", CHNOSZ)
   # if we're called with NA, return an empty row
   if(is.na(ispecies)) {
     this <- thermo$obigt[1,]
@@ -194,7 +196,8 @@ info.numeric <- function(ispecies, check.it=TRUE) {
     this[, which(naGHS)+7] <- GHS[naGHS]
   } 
   # now perform consistency checks for GHS and EOS parameters if check.it=TRUE
-  if(check.it) {
+  # don't do it for the AkDi species 20190219
+  if(check.it & !"xi" %in% colnames(this)) {
     # check GHS if they were all present
     if(sum(naGHS)==0) calcG <- checkGHS(this)
     # check tabulated heat capacities against EOS parameters
@@ -222,7 +225,7 @@ info.approx <- function(species, state=NULL) {
   # returns species indices that have an approximate match of 'species'
   # to thermo$obigt$[name|abbrv|formula], 
   # possibly restricted to a given state
-  thermo <- get("thermo")
+  thermo <- get("thermo", CHNOSZ)
   if(!is.null(state)) this <- thermo$obigt[thermo$obigt$state==state, ]
   else this <- thermo$obigt
   # only look for fairly close matches
@@ -248,7 +251,7 @@ info.approx <- function(species, state=NULL) {
   }
   # if we got here there were no approximate matches
   # 20190127 look for the species in optional data files 
-  for(opt in c("SLOP98", "SUPCRT92", "OldAA")) {
+  for(opt in c("SLOP98", "SUPCRT92", "OldAA", "AkDi")) {
     optdat <- read.csv(system.file(paste0("extdata/OBIGT/", opt, ".csv"), package="CHNOSZ"), as.is=TRUE)
     if(species %in% optdat$name) {
       message('info.approx: ', species, ' is in an optional database; use add.obigt("', opt, '", "', species, '") to load it')
