@@ -5,42 +5,42 @@
 ## set up plotting area
 opar <- par(mfrow=c(2, 2))
 
-## start with default database
-data(thermo)
-
 ###########
 ### plot 1: boehmite - kaolinite equilibrium
 ###########
 ## experimental data from Table 1 of Hemley et al., 1980
 # doi:10.2113/gsecongeo.75.2.210
-xT <- c(200, 200, 200, 200, 250, 250, 300, 300, 300, 300)
-xlogaSiO2 <- -c(2.54, 2.59, 2.65, 2.77, 2.21, 2.32, 1.90, 1.95, 1.94, 1.90)
+xT <- c(200, 200, 200, 200, 250, 250, 265, 300, 300, 300, 300)
+xlogaSiO2 <- -c(2.54, 2.59, 2.65, 2.77, 2.21, 2.32, 2.12, 1.90, 1.95, 1.94, 1.90)
 ## set up basis species so that axis.label shows activity of SiO2
 basis(c("Al2O3","SiO2", "H2O", "O2"))
 T <- 125:350
 thermo.plot.new(xlim=range(T), ylim=c(-3.5, -1.5), xlab = axis.label("T"), ylab=axis.label("SiO2"))
 points(xT, xlogaSiO2)
 basis(delete=TRUE)
-## first calculation: after SUPCRT92 and SLOP98
+## first calculation: as in SUPCRT92
 add.obigt("SUPCRT92") # gets kaolinite and boehmite from HDNB78
-add.obigt("SLOP98") # SiO2(aq) from SHS89
 r1 <- subcrt(c("boehmite", "H2O", "SiO2", "kaolinite"), c(-1, -0.5, -1, 0.5), T=T, P=1000, exceed.Ttr = TRUE) 
 # we need exceed.Ttr = TRUE because the T limit for boehmite is 500 K (Helgeson et al., 1978)
 ## second calculation: CHNOSZ default
 # kaolinite from Berman, 1988
 # boehmite from Hemingway et al., 1991
 # SiO2 from Apps and Spycher, 2004
-data(thermo)
+reset()
 r2 <- subcrt(c("boehmite", "H2O", "SiO2", "kaolinite"), c(-1, -0.5, -1, 0.5), T=T, P=1000, exceed.Ttr = TRUE) 
+## third calculation: get SiO2(aq) from SHS89
+add.obigt("AS04")
+r3 <- subcrt(c("boehmite", "H2O", "SiO2", "kaolinite"), c(-1, -0.5, -1, 0.5), T=T, P=1000, exceed.Ttr = TRUE) 
 ## log activity of SiO2 is -ve logK
 lines(T, -r1$out$logK)
 lines(T, -r2$out$logK, col="red")
+lines(T, -r3$out$logK, col="red", lty = 2)
 ## add points calculated using the SUPCRTBL package
 points(seq(125, 350, 25), -c(3.489, 3.217, 2.967, 2.734, 2.517, 2.314, 2.124, 1.946, 1.781, 1.628), pch=4, col="red")
 ## add legend and title
-legend("topleft", lty=c(0, 1, 0, 1), pch=c(1, NA, 4, NA),
-       col=c("black", "black", "red", "red"), bty="n", cex=0.9,
-       legend=c("Hemley et al., 1980", "SUPCRT92/SLOP98", "SUPCRTBL", "CHNOSZ"))
+legend("bottomright", lty=c(0, 0, 1, 1, 2), pch=c(1, 4, NA, NA, NA),
+       col=c("black", "red", "black", "red", "red"), bty="n", cex=0.9,
+       legend=c("Hemley et al., 1980", "SUPCRTBL", "SUPCRT92", "CHNOSZ (default)", 'add.obigt("AS04")'))
 mtitle(c("Kaolinite - Boehmite", "After Zhu and Lu, 2009 Fig. A1"), cex=0.95)
 # Zhu and Lu, 2009: doi:10.1016/j.gca.2009.03.015
 # Helgeson et al., 1978 (HDNB78): http://www.worldcat.org/oclc/13594862
@@ -73,8 +73,8 @@ lines(T, Daw2$out$logK, col="red", lty=2)
 ## add points calculated using the SUPCRTBL package
 points(seq(25, 250, 25), c(-17.829, -16.523, -15.402, -14.425, -13.568, -12.815, -12.154, -11.581, -11.094, -10.699), pch=4, col="red")
 ## add legend and title
-legend("topleft", lty=c(0, 1, 0, 2), pch=c(1, NA, 4, NA), col=c("black", "red", "red", "red"),
-       bty="n", cex=0.9, legend=c("Ben\u00e9z\u00e9th et al., 2007", "CHNOSZ", "SUPCRTBL", "Cp(dawsonite) = 0"))
+legend("bottomright", lty=c(0, 0, 1, 2), pch=c(1, 4, NA, NA), col=c("black", "red", "red", "red"),
+       bty="n", cex=0.9, legend=c("Ben\u00e9z\u00e9th et al., 2007", "SUPCRTBL", "CHNOSZ", 'mod.obigt("dawsonite", Cp = 0)'))
 mtitle(c("Dawsonite - aqueous species", "After Zimmer et al., 2016 Fig. 2"), cex=0.95)
 # doi:10.1016/j.cageo.2016.02.013
 
@@ -134,6 +134,6 @@ mtitle(c("Aqueous aluminum species",
 ###########
 ### clean up: restore thermodynamic database to default
 ###########
-data(thermo)
+reset()
 
 par(opar)
